#ifndef VENUEDETAILS_H
#define VENUEDETAILS_H

#include <QWidget>
#include "foursquarecomm.h"
#include <QLabel>
#include "checkindetails.h"

namespace Ui {
    class VenueDetails;
}

class VenueDetails : public QWidget
{
    Q_OBJECT

public:
    explicit VenueDetails(QWidget *parent = 0);
    ~VenueDetails();
public slots:
    void setVenue(f_venue v);
    void getVenueDetails(QString id);
private:
    Ui::VenueDetails *ui;
    f_venue venue;
    void setLabelText(QLabel * l, QString s);
    FoursquareComm * fsc;
    ImageCache * ic;
    CheckinDetails * cd;


private slots:
    void on_pbCheckin_clicked();
};

#endif // VENUEDETAILS_H
